@@ -11,7 +11,7 @@ class ErrorUseWithSuppress(Error):
     """
     Often times you want to handle an exception, and just ignore it. You can do
     this with a `try/except` block, using a single `pass` in the `except`
-    block, but there is a simpler and more consice way using the `suppress()`
+    block, but there is a simpler and more concise way using the `suppress()`
     method from `contextlib`:
 
     Bad:
@@ -53,10 +53,12 @@ def check(node: TryStmt, errors: list[Error]) -> None:
                     tmp = ", ".join(cast(NameExpr, exc).name for exc in items)
                     inner = f"({tmp})"
 
+            except_inner = f" {inner}" if inner else ""
+
             errors.append(
                 ErrorUseWithSuppress(
                     node.line,
                     node.column,
-                    f"Use `with suppress({inner}): ...` instead of `try: ... except: pass`",  # noqa: E501
+                    f"Use `with suppress({inner}): ...` instead of `try: ... except{except_inner}: pass`",  # noqa: E501
                 )
             )
