@@ -16,7 +16,7 @@ from refurb.error import Error
 @dataclass
 class ErrorNoWithAssign(Error):
     """
-    Due to Python's scoping rules, you can use a variable which has gone "out
+    Due to Python's scoping rules, you can use a variable that has gone "out
     of scope" so long as all previous code paths can bind to it. Long story
     short, you don't need to declare a variable before you assign it in a
     `with` statement:
@@ -47,16 +47,20 @@ def check(node: Block | MypyFile, errors: list[Error]) -> None:
 
 
 def check_stmts(body: list[Statement], errors: list[Error]) -> None:
-    assign = None
+    assign: AssignmentStmt | None = None
 
     for stmt in body:
         if assign:
-            match stmt:  # type: ignore
+            match stmt:
                 case WithStmt(
                     body=Block(
                         body=[AssignmentStmt(lvalues=[NameExpr() as name])]
                     )
-                ) if name.fullname == assign.lvalues[0].fullname:
+                ) if (
+                    name.fullname
+                    and name.fullname
+                    == assign.lvalues[0].fullname  # type: ignore
+                ):
                     errors.append(
                         ErrorNoWithAssign(assign.line, assign.column)
                     )
